@@ -3,7 +3,7 @@
 #
 #  This file is part of the easydev software
 #
-#  Copyright (c) 2012-2014 - 
+#  Copyright (c) 2012-2014 -
 #
 #  File author(s): Thomas Cokelaer (cokelaer, gmail.com)
 #
@@ -11,13 +11,16 @@
 #  See accompanying file LICENSE.txt or copy at
 #      http://www.gnu.org/licenses/gpl-3.0.html
 #
-#  website: http://thomas-cokelaer.info
+#  Website: https://github.com/cokelaer/easydev
+#  website: http://github.com/cokelaer/easydev
 #
 ##############################################################################
 # $Id: tools.py 2963 2012-12-17 14:31:26Z cokelaer $
 """Handy decorators"""
-from functools import partial, wraps, update_wrapper
-__all__ = [ 'requires']
+from functools import wraps
+import threading
+
+__all__ = ['ifpylab', 'requires', 'ifpandas']
 
 
 # decorator with arguments and optional arguments for a method
@@ -38,7 +41,7 @@ def _require(*args_deco, **kwds_deco):
         t.print()
 
 
-    .. todo:: first argument could be a list 
+    .. todo:: first argument could be a list
     """
     if len(args_deco) != 2:
         raise ValueError("require decorator expects 2 parameter. First one is" +
@@ -46,7 +49,7 @@ def _require(*args_deco, **kwds_deco):
     attribute = args_deco[0]
     msg = args_deco[1]
 
-    if len(attribute.split('.'))>2:
+    if len(attribute.split('.')) > 2:
         raise AttributeError('This version of require decorator introspect only 2 levels')
 
     def decorator(func):
@@ -62,14 +65,14 @@ def _require(*args_deco, **kwds_deco):
 
             if len(names) == 1:
                 if hasattr(args[0], attribute):
-                   return func(*args, **kwds)
+                    return func(*args, **kwds)
                 else:
-                   raise AttributeError('%s not found. %s' % (names, msg))
+                    raise AttributeError('%s not found. %s' % (names, msg))
             elif len(names) == 2:
                 if hasattr(getattr(args[0], names[0]), names[1]):
                     return func(*args, **kwds)
                 else:
-                   raise AttributeError('%s not found. %s' % (names, msg))
+                    raise AttributeError('%s not found. %s' % (names, msg))
 
         newf.__name__ = func.__name__
         newf.__doc__ = func.__doc__
@@ -80,23 +83,24 @@ def _require(*args_deco, **kwds_deco):
 
 # for book keeping, could be useful:
 def _blocking(not_avail):
-    import threading
     def blocking(f, *args, **kw):
-        if not hasattr(f, "thread"): # no thread running
-            def set_result(): f.result = f(*args, **kw)
+        if not hasattr(f, "thread"):
+            # no thread running
+            def set_result():
+                f.result = f(*args, **kw)
             f.thread = threading.Thread(None, set_result)
             f.thread.start()
             return not_avail
         elif f.thread.isAlive():
             return not_avail
-        else: # the thread is ended, return the stored result
+        else:
+            # the thread is ended, return the stored result
             del f.thread
             return f.result
     return blocking
 
 
-
-# same as require decorator but works with list of stirngs of 
+# same as require decorator but works with list of stirngs of
 # single string and uses the functools utilities
 def requires(requires, msg=""):
     """Decorator for class method to check if an attribute exist
@@ -128,8 +132,46 @@ def requires(requires, msg=""):
         def wrapper(*args, **kwds):
             for require in requires:
                 if hasattr(args[0], require) == False:
-                    raise AttributeError("{} not found in {}. ".format(require, args[0]) + msg) 
+                    raise AttributeError("{} not found in {}. ".format(require, args[0]) + msg)
             return f(*args, **kwds)
         return wrapper
     return actualDecorator
 
+
+# could be a macro maybe
+
+def ifpandas(func):
+    """check if pandas is available. If so, just return
+    the function, otherwise returns dumming function
+    that does nothing
+
+    """
+    def wrapper(*args, **kwds):
+        return func(*args, **kwds)
+
+    try:
+        import pandas
+        return wrapper
+    except Exception:
+        def dummy():
+            pass
+        return dummy
+
+
+def ifpylab(func):
+    """check if pandas is available. If so, just return
+    the function, otherwise returns dumming function
+    that does nothing
+
+    """
+    # for functions
+    def wrapper(*args, **kwds):
+        return func(*args, **kwds)
+    # for methods
+    try:
+        import pylab
+        return wrapper
+    except Exception:
+        def dummy():
+            pass
+        return dummy
