@@ -3,7 +3,7 @@
 #
 #  This file is part of the easydev software
 #
-#  Copyright (c) 2011-2013 
+#  Copyright (c) 2011-2013
 #
 #  File author(s): Thomas Cokelaer <cokelaer@gmail.com>
 #
@@ -11,7 +11,7 @@
 #  See accompanying file LICENSE.txt or copy at
 #      http://www.gnu.org/licenses/gpl-3.0.html
 #
-#  Website: https://www.assembla.com/spaces/pyeasydev/wiki
+#  Website: https://github.com/cokelaer/easydev
 #  Documentation: http://packages.python.org/easydev
 #
 ##############################################################################
@@ -36,22 +36,18 @@ Based on OpenAlea.Misc http://openalea.gforge.inria.fr
 """
 
 __license__ = "GPLv3"
-__revision__ = " $Id: multisetup.py 65 2014-05-06 09:20:23Z cokelaer $"
+__revision__ = " $Id$"
 
 import sys
 import os
-#from optparse import OptionParser
 from subprocess import PIPE, Popen
 
 
 try:
     from easydev.console import bold, red, green, \
         color_terminal, nocolor, underline, purple
-except:
-    pj = os.path.join
-    sys.path.insert(0, pj('deploy', 'src', 'deploy'))
-    from console import bold, red, green, \
-        color_terminal, nocolor, underline, purple
+except ImportError:
+    pass
 
 
 """
@@ -107,7 +103,7 @@ class Multisetup(object):
         if 'develop -u' in " ".join(commands):
             packages.reverse()
 
-        #default
+        # default
         self.curdir = os.path.abspath(curdir)
 
         if isinstance(commands, list):
@@ -122,10 +118,10 @@ class Multisetup(object):
         self.verbose = verbose
         self.force = False
 
-        #parsing user arguments
+        # parsing user arguments
         self.parse_packages()
 
-        #self.parse_intern_commands()
+        # self.parse_intern_commands()
         self.parse_commands()
 
 
@@ -133,7 +129,7 @@ class Multisetup(object):
     def help(cls):
         """help: to get more help and usage
         """
-        print """
+        print("""
 
         MultiSetup allows to build and install all the packages found in this
         directory usinf the same commands and setuptools.
@@ -163,7 +159,7 @@ class Multisetup(object):
           --exclude-packages             list of packages to not run
 
         print "usage: multisetup.py [global_opts] cmd1 [cmd1_opts] [cmd2 [cmd2_opts] ...]
-        """
+        """)
 
 
     def parse_packages(self):
@@ -281,39 +277,39 @@ class Multisetup(object):
         else:
             bold = purple = red = green = underline = str
 
-        print bold("Running multisetup version %s" % __revision__.split()[2])
+        print(bold("Running multisetup version %s" % __revision__.split()[2]))
 
         #project_dir = self.curdir.basename()
         directories = [package for package in self.packages]
 
 
-        print 'Will process the following directories: ',
+        print('Will process the following directories: ',)
         for directory in directories:
             print(bold(directory)),
             #print bold(directory.basename()),
-        print ''
+        print('')
 
 
         try:
             for directory in directories:
                 try:
                     os.chdir(directory)
-                    print underline('Entering %s package'
-                          % os.path.basename(directory))
+                    print(underline('Entering %s package'
+                          % os.path.basename(directory)))
                           #          % directory.basename())
-                except OSError, e:
-                    print underline('Entering %s package'
-                              % os.path.basename(directory))
-                    print red("cannot find this directory (%s)"
-                              % os.path.basename(directory))
-                    print e
+                except OSError as err:
+                    print(underline('Entering %s package'
+                              % os.path.basename(directory)))
+                    print(red("cannot find this directory (%s)"
+                              % os.path.basename(directory)))
+                    print(err)
 
-                print 'Python exec : ' , sys.executable
+                print('Python exec : ' , sys.executable)
 
                 #print underline('Entering %s package' % directory.basename())
                 for cmd in self.commands:
                     setup_command = '%s setup.py %s ' % (sys.executable,cmd)
-                    print "\tExecuting " + setup_command + '...processing',
+                    print("\tExecuting " + setup_command + '...processing',)
 
 
                     #Run setup.py with user commands
@@ -329,11 +325,11 @@ class Multisetup(object):
                         #status = process.wait()
                         outputs, errors = process.communicate()
                     if process.returncode == 0:
-                        print green('done')
+                        print(green('done'))
                     else:
                         if not self.verbose:
-                            print red('\tFailed. ( error code %s) ' %
-                                  (process.returncode))
+                            print(red('\tFailed. ( error code %s) ' %
+                                  (process.returncode)))
                             os.chdir(self.curdir)
 
                         if not self.force:
@@ -343,20 +339,20 @@ class Multisetup(object):
                         if outputs is not None:
                             for x in outputs.split('\n'):
                                 if x.startswith('Your code has been'):
-                                    print purple('\t%s' % x)
+                                    print(purple('\t%s' % x))
                     if 'nosetests' in cmd:
                         if errors is not None:
                             for x in errors.split('\n'):
                                 if x.startswith('TOTAL'):
                                     res = x.replace('TOTAL', 'Total coverage')
                                     res = " ".join (res.split())
-                                    print purple('\t%s' % res)
+                                    print(purple('\t%s' % res))
                                 if x.startswith('Ran'):
-                                    print purple('\t%s' % x)
+                                    print(purple('\t%s' % x))
                                 if x.startswith('FAILED'):
-                                    print purple('\t%s' % x)
+                                    print(purple('\t%s' % x))
                         else:
-                            print purple('all right')
+                            print(purple('all right'))
 
                 os.chdir(self.curdir)
 
